@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,6 @@
 #define HEADER_SUPERTUX_OBJECT_BONUS_BLOCK_HPP
 
 #include "object/block.hpp"
-#include "object/player.hpp"
-#include "object/moving_sprite.hpp"
 
 class BonusBlock : public Block
 {
@@ -29,23 +27,15 @@ public:
   virtual ~BonusBlock();
   HitResponse collision(GameObject& other, const CollisionHit& hit);
 
-  void try_open(Player *player);
-  void try_drop(Player *player);
+  void try_open();
 
   enum Contents {
     CONTENT_COIN,
     CONTENT_FIREGROW,
     CONTENT_ICEGROW,
-    CONTENT_AIRGROW,
-    CONTENT_EARTHGROW,
     CONTENT_STAR,
     CONTENT_1UP,
-    CONTENT_CUSTOM,
-    CONTENT_SCRIPT,
-    CONTENT_LIGHT,
-    CONTENT_TRAMPOLINE,
-    CONTENT_RAIN,
-    CONTENT_EXPLODE
+    CONTENT_CUSTOM
   };
 
 protected:
@@ -53,20 +43,11 @@ protected:
 
 public:
   Contents contents;
-  std::shared_ptr<MovingObject> object;
-  int hit_counter;
-  void draw(DrawingContext& context);
+  MovingObject* object;
 
 private:
   BonusBlock(const BonusBlock&);
   BonusBlock& operator=(const BonusBlock&);
-  std::string sprite_name;
-  std::string script;
-  SurfacePtr lightsprite;
-  void get_content_by_data(int d);
-  void raise_growup_bonus(Player* player, const BonusType& bonus, const Direction& dir);
-  void drop_growup_bonus(const std::string& bonus_sprite_name, bool& countdown);
-  BonusBlock::Contents get_content_from_string(const std::string& contentstring) const;
 };
 
 #endif
